from lazyTest.file import GetElementSource,ReadIni,ReadCsvFileToList
from lazyTest.utils import Sleep, clearLogAndReport, createData,cls_Sleep
from lazyTest.case import TestCase
from lazyTest.base import  WebOption
from lazyTest.page import Page

__version__ = '2.0.5'


__author__ = 'buxiubuzhi'

__description__ = "WebUI自动化测试框架"

__all__ = [
    "Sleep",
    "Page",
    "clearLogAndReport",
    "WebOption",
    "createData",
    "TestCase",
    "cls_Sleep",
    "GetElementSource",
    "ReadIni",
    "ReadCsvFileToList"
]
